/*
  Rui Santos
  Complete project details at https://RandomNerdTutorials.com/esp8266-client-server-wi-fi/
  
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files.
  
  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.
*/

#include <ESP8266WiFi.h>
#include <ESP8266HTTPClient.h>
#include <WiFiClient.h>

#include <ESP8266WiFiMulti.h>
ESP8266WiFiMulti WiFiMulti;

const char* ssid = "ESP8266-Access-Point";
const char* password = "123456789";

//ip adderess of temperature request
const char* serverNameJoint1 = "http://192.168.4.1/joint1";
const char* serverNameJoint2 = "http://192.168.4.1/joint2";
const char* serverNameJoint3 = "http://192.168.4.1/joint3";

//received value saves here
String joint1; 
String joint2;
String joint3;

unsigned long previousMillis = 0;
const long interval = 1; 

void setup() {
  Serial.begin(115200);
  Serial.println();
  
 
  WiFi.mode(WIFI_STA);
  WiFiMulti.addAP(ssid, password);
  while((WiFiMulti.run() == WL_CONNECTED)) { 
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.println("Connected to WiFi");
}

void loop() {
  unsigned long currentMillis = millis();
  
  if(currentMillis - previousMillis >= interval) 
  {
     // Check WiFi connection status
    if ((WiFiMulti.run() == WL_CONNECTED)) 
    {
      joint1 = httpGETRequest(serverNameJoint1);
      joint2 = httpGETRequest(serverNameJoint2);
      joint3 = httpGETRequest(serverNameJoint3);

      Serial.print("joint1=");   Serial.print(joint1);
      Serial.print("\tjoint2="); Serial.print(joint2);
      Serial.print("\tjoint3="); Serial.print(joint3);
      Serial.println(); 

      // save the last HTTP GET Request
      previousMillis = currentMillis;
    }
    else 
    {
      Serial.println("WiFi Disconnected");
    }
  }
}

String httpGETRequest(const char* serverName) 
{
  WiFiClient client;
  HTTPClient http;
    
  // Your IP address with path or Domain name with URL path 
  http.begin(client, serverName);
  
  // Send HTTP POST request
  int httpResponseCode = http.GET();
  
  String payload = "--"; 
  
  if (httpResponseCode>0) {
    //Serial.print("HTTP Response code: ");
    //Serial.println(httpResponseCode);
    payload = http.getString();
  }
  else {
    //Serial.print("Error code: ");
    //Serial.println(httpResponseCode);
  }
  // Free resources
  http.end();

  return payload;
}
